==> jc-1.4.0.tar.gz: soot/baf/internal/AbstractOpTypeInst.h <==
// public abstract class soot.baf.internal.AbstractOpTypeInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 34018fa9b43e3c40 soot_baf_internal_AbstractOpTypeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_AbstractOpTypeInst_H_
#define _JC_soot_baf_internal_AbstractOpTypeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	_jc_soot_baf_internal_AbstractOpTypeInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	_jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$refs	_jc_soot_baf_internal_AbstractOpTypeInst$refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$nonrefs	_jc_soot_baf_internal_AbstractOpTypeInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$object	_jc_soot_baf_internal_AbstractOpTypeInst$object;

typedef const struct _jc_soot_baf_internal_AbstractOpTypeInst$vmethods	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeInst$vtable	_jc_soot_baf_internal_AbstractOpTypeInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeInst$vtype	_jc_soot_baf_internal_AbstractOpTypeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractOpTypeInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_AbstractOpTypeInst$method$getOpType$2611df5c7a014636(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *);
extern jint _jc_soot_baf_internal_AbstractOpTypeInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *);
extern void _jc_soot_baf_internal_AbstractOpTypeInst$method$setOpType$96cc62a0f09a0473(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_soot_Type$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractOpTypeInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *);
extern void _jc_soot_baf_internal_AbstractOpTypeInst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$getOpType$2611df5c7a014636;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$getOutMachineCount$382bb5439d011100;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$setOpType$96cc62a0f09a0473;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractOpTypeInst$vmethods {
	struct _jc_soot_Type$object	*(*getOpType$2611df5c7a014636)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *);
	void	(*setOpType$96cc62a0f09a0473)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_soot_Type$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_internal_AbstractOpTypeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods	soot_baf_internal_AbstractOpTypeInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractOpTypeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractOpTypeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs {
	struct _jc_soot_Type$object	*opType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeInst$refs {
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractOpTypeInst$object {
	_jc_soot_baf_internal_AbstractOpTypeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractOpTypeInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractOpTypeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractOpTypeInst$vtype _jc_soot_baf_internal_AbstractOpTypeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractOpTypeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractOpTypeInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractOpTypeInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/AbstractOpTypeInst.h <==
// public abstract class soot.baf.internal.AbstractOpTypeInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 34018fa9b43e3c40 soot_baf_internal_AbstractOpTypeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_AbstractOpTypeInst_H_
#define _JC_soot_baf_internal_AbstractOpTypeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	_jc_soot_baf_internal_AbstractOpTypeInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	_jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$refs	_jc_soot_baf_internal_AbstractOpTypeInst$refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$nonrefs	_jc_soot_baf_internal_AbstractOpTypeInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeInst$object	_jc_soot_baf_internal_AbstractOpTypeInst$object;

typedef const struct _jc_soot_baf_internal_AbstractOpTypeInst$vmethods	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeInst$vtable	_jc_soot_baf_internal_AbstractOpTypeInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeInst$vtype	_jc_soot_baf_internal_AbstractOpTypeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractOpTypeInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_AbstractOpTypeInst$method$getOpType$2611df5c7a014636(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_AbstractOpTypeInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractOpTypeInst$method$setOpType$96cc62a0f09a0473(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractOpTypeInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractOpTypeInst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$getOpType$2611df5c7a014636;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$getOutMachineCount$382bb5439d011100;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$setOpType$96cc62a0f09a0473;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeInst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractOpTypeInst$vmethods {
	struct _jc_soot_Type$object	*(*getOpType$2611df5c7a014636)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *) _JC_JCNI_ATTR;
	void	(*setOpType$96cc62a0f09a0473)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_AbstractOpTypeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods	soot_baf_internal_AbstractOpTypeInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractOpTypeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractOpTypeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs {
	struct _jc_soot_Type$object	*opType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeInst$refs {
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractOpTypeInst$object {
	_jc_soot_baf_internal_AbstractOpTypeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractOpTypeInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractOpTypeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractOpTypeInst$vtype _jc_soot_baf_internal_AbstractOpTypeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractOpTypeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractOpTypeInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractOpTypeInst_H_ */
